Learn R Programming

acmeR (version 1.1.0)

acme.est: Parameter Estimation for Persistence and Search Proficiency

Description

Finds Maximum Likelihood Estimates Weibull persistence parameters, and for exponentially decreasing search proficiency.

Usage

acme.est(rd, fname = "acme.est")

Arguments

rd
list output from acme::read.data()
fname
file name to which the output parameters are saved

Value

acme.est returns a list with the following components:
params
5-element vector: alpha and rho parameters for the Weibull persistence distribution, a and b parameters for the exponentially decreasing search proficiency, and bt as the bleed-through rate
info
list of select system information inherited from acme::read.data() output