Learn R Programming

acmeR (version 1.1.0)

acme.table: Posterior Summary of Mortality

Description

Calculates and summarizes the posterior distribution of mortality count.

Usage

acme.table(C = 0, Rstar = 0.2496, T = 0.174, gam = c(0.5, 0.9), I = 7, Mmax = 200, xi = 1/2, lam = 0)

Arguments

C
Observed mortality count. Non-negative integer or vector.
Rstar
ACME inverse-inflation factor R*, reported by acme.summary() as "Rstar."
T
The first term in recursive calculation of Rstar, from acme.summary.
gam
Values for highest posterior density credible interval.
I
Interval length, days.
Mmax
Maximimum value for which posterior probability is calculated.
xi
First parameter of gamma prior. Default is 1/2 for Objective prior.
lam
Second parameter of gamma prior. Default is 0 for Objective prior.

Value

acme.table returns a table which includes ACME estimate (M_hat), posterior mean, and highest posterior credible intervals for probabilities as specified by the parameter gam.

Details

Assuming a Gamma(xi, lam) on the average daily mortality rate m, this model treats the mortality M for the current period as Poisson-distributed with mean m*I. The carcass count C will include "new" carcasses with a Bi(M,T) distribution as well as "old" carcasses (if bt > 0). For derivation of resulting conditional pdf see Wolpert (2015).

This function calls acme.post but suppresses plotting.

Examples

Run this code
acme.table(C=0:5,Rstar = 0.2496, T = 0.174)

Run the code above in your browser using DataLab