Learn R Programming

acmeR (version 1.1.0)

altamont: Placement and Searches for Carcasses at Altamont

Description

An event-level dataset containing information pertinent to the ACME model, from Warren-Hicks et al. (2012), "Improving Methods for Estimating Fatality of Birds and Bats at Wind Energy Facilities."

Usage

altamont

Arguments

Format

A data frame with 3984 observations and 6 variables:
Date
character - Data of the event
Time
character - Time of the event
ID
character - ID of the carcass
Species
character - 4-letter AOU species code
Event
character - Type of event - Check, Place, or Search
Found
logical - TRUE if carcass was discovered

Warren-Hicks, W., Newman, J., Wolpert, R. L., Karas, B., and Tran, L. (2012), Improving Methods for Estimating Fatality of Birds and Bats at Wind Energy Facilities, California Wind Energy Association publication CEC-500-2012-086.